"use strict";

var _assign = require("babel-runtime/core-js/object/assign");

var _assign2 = _interopRequireDefault(_assign);

var _classCallCheck2 = require("babel-runtime/helpers/classCallCheck");

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require("babel-runtime/helpers/createClass");

var _createClass3 = _interopRequireDefault(_createClass2);

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

var _reactDom = require("react-dom");

var _reactDom2 = _interopRequireDefault(_reactDom);

var _winston = require("winston");

var _winston2 = _interopRequireDefault(_winston);

var _Server = require("./classes/Server");

var _Server2 = _interopRequireDefault(_Server);

var _Webpack = require("./classes/Webpack");

var _Webpack2 = _interopRequireDefault(_Webpack);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = function () {
  function ExtensiveReactServer(props) {
    (0, _classCallCheck3.default)(this, ExtensiveReactServer);

    this.config = (0, _assign2.default)({
      environment: "development",
      hostname: "localhost",
      port: 3000,

      options: {
        logToFile: false,
        logFile: "server.log",

        logRequests: true,
        useJsonPretty: true,
        useEtags: false,

        useHelmet: true,
        helmetOptions: {
          noCache: true,
          frameguard: {
            action: "deny"
          }
        },
        useCompress: true,
        compressOptions: {
          threshold: 2048
        },

        useDdos: true,
        ddosOptions: {
          burst: 10,
          limit: 15
        },

        useCors: true,
        corsOptions: {
          origin: "*"
        }
      }
    }, props);

    var transports = [new _winston2.default.transports.Console()];
    if (this.config.options.logToFile) transports.push(new _winston2.default.transports.File({ filename: this.config.options.logFile }));

    this.logger = new _winston2.default.Logger({
      level: this.config.options.logLevel,
      transports: transports
    });

    this.server = new _Server2.default({}, this);
    this.webpack = new _Webpack2.default({}, this);
    this.logger.info("[ExtServer] - Creating instance..");
  }

  /**
   * Starts the engine
   */


  (0, _createClass3.default)(ExtensiveReactServer, [{
    key: "start",
    value: function start() {
      this.server.start();
    }

    /**
     * Adds routes to the route config
     * @param {array} routes [route, route2, routefolder, routefolder3]
     */

  }, {
    key: "addRouteFolder",
    value: function addRouteFolder(routes) {
      this.server.router.addRouteFolder(route);
    }

    /**
     * Adds a route file or folder to the route config
     * @param {string} route path/to/route.js
     */

  }, {
    key: "addRoute",
    value: function addRoute(route) {
      this.server.router.addRoute(route);
    }

    /**
     * [description]
     * @param {[type]}
     */

  }, {
    key: "addStaticFile",
    value: function addStaticFile(filePath, servePath) {
      this.server.router.addStaticFile(filePath, servePath);
    }

    /**
     * [description]
     * @param {[type]}
     */

  }, {
    key: "addStaticFolder",
    value: function addStaticFolder(filePath, servePath) {
      this.server.router.addStaticFolder(filePath, servePath);
    }

    /**
     * Adds a react app to the route
     * @param {string} prefix        [description]
     * @param {FoundRouter} router   [description]
     * @param {Object} webpackClient [description]
     * @param {Object} webpackServer [description]
     * @param {object} options       [description]
     * @param {array} middleware    [description]
     */

  }, {
    key: "addReactRoute",
    value: function addReactRoute(prefix, app) {
      var webpackClient = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      var webpackServer = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
      var options = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : {};
      var middleware = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : [];

      return this.server.addReactRoute(prefix, app, webpackClient, webpackServer, options, middleware);
    }
  }, {
    key: "__reactstandin__regenerateByEval",
    value: function __reactstandin__regenerateByEval(key, code) {
      this[key] = eval(code);
    }
  }]);
  return ExtensiveReactServer;
}();